"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.authenticate = authenticate;

var _NativeBiometricsScanner = _interopRequireDefault(require("./NativeBiometricsScanner"));

var _errors = require("./errors");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 *
 * @param prompt - object defining the prompt to show
 * @return {Promise<void>}
 *
 * @throws {@link BiometricUnknownError} when biometric status is unknown
 * @throws {@link BiometricUnsupportedError} when biometric is not supported
 * @throws {@link BiometricNoEnrollError} when user must enroll to use biometric
 * @throws {@link BiometricAuthenticationError} when an authentication error has occurred
 * @throws {@link BiometricUserCancelError} when user cancels authentication
 * @throws {@link BiometricFallbackError} when user tap fallback button
 * @throws {@link BiometricSystemCancelError} when system cancels authenitcation
 * @throws {@link BiometricPasscodeNotSetError} when passcode is not set
 * @throws {@link BiometricLockOutError} when user is locked out
 */
async function authenticate(prompt) {
  try {
    await _NativeBiometricsScanner.default.authenticate(prompt);
  } catch (error) {
    const errorGenerator = _errors.ErrorMap[error.code];
    throw errorGenerator ? errorGenerator() : error;
  }
}
//# sourceMappingURL=authenticate.js.map