"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ErrorMap = exports.BiometricUserCancelError = exports.BiometricUnsupportedError = exports.BiometricUnknownError = exports.BiometricSystemCancelError = exports.BiometricPasscodeNotSetError = exports.BiometricNoEnrollError = exports.BiometricLockOutError = exports.BiometricFallbackError = exports.BiometricAuthenticationError = void 0;

class BiometricUnknownError extends Error {
  constructor() {
    super('Biometric status is unknown');
    this.name = 'BiometricUnknownError';
  }

}

exports.BiometricUnknownError = BiometricUnknownError;

class BiometricUnsupportedError extends Error {
  constructor() {
    super('Biometric type is not supported');
    this.name = 'BiometricUnsupportedError';
  }

}

exports.BiometricUnsupportedError = BiometricUnsupportedError;

class BiometricNoEnrollError extends Error {
  constructor() {
    super('User is not enrolled to use biometrics');
    this.name = 'BiometricNoEnrollError';
  }

}

exports.BiometricNoEnrollError = BiometricNoEnrollError;

class BiometricAuthenticationError extends Error {
  constructor() {
    super('User failed to authenticate with biometrics');
    this.name = 'BiometricAuthenticationError';
  }

}

exports.BiometricAuthenticationError = BiometricAuthenticationError;

class BiometricUserCancelError extends Error {
  constructor() {
    super('User cancelled biometric authentication');
    this.name = 'BiometricUserCancelError';
  }

}

exports.BiometricUserCancelError = BiometricUserCancelError;

class BiometricSystemCancelError extends Error {
  constructor() {
    super('System cancelled biometric authentication');
    this.name = 'BiometricSystemCancelError';
  }

}

exports.BiometricSystemCancelError = BiometricSystemCancelError;

class BiometricFallbackError extends Error {
  constructor() {
    super('Fallback authentication method failed');
    this.name = 'BiometricFallbackError';
  }

}

exports.BiometricFallbackError = BiometricFallbackError;

class BiometricPasscodeNotSetError extends Error {
  constructor() {
    super('Passcode not set');
    this.name = 'BiometricPasscodeNotSetError';
  }

}

exports.BiometricPasscodeNotSetError = BiometricPasscodeNotSetError;

class BiometricLockOutError extends Error {}

exports.BiometricLockOutError = BiometricLockOutError;
const ErrorMap = {
  106: () => new BiometricLockOutError(),
  105: () => new BiometricPasscodeNotSetError(),
  104: () => new BiometricSystemCancelError(),
  103: () => new BiometricFallbackError(),
  102: () => new BiometricUserCancelError(),
  101: () => new BiometricAuthenticationError(),
  99: () => new BiometricNoEnrollError(),
  98: () => new BiometricUnsupportedError(),
  97: () => new BiometricUnknownError()
};
exports.ErrorMap = ErrorMap;
//# sourceMappingURL=errors.js.map