"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getAvailableBiometric = getAvailableBiometric;

var _NativeBiometricsScanner = _interopRequireDefault(require("./NativeBiometricsScanner"));

var _errors = require("./errors");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @param allowDeviceCredentials - check if using device credential as fallback
 * @return {Promise<BiometricType>} of the hardware
 *
 * @throws {@link UnknownBiometricError} when biometric status is unknown
 * @throws {@link UnsupportedBiometricError} when biometric is not supported
 * @throws {@link NoEnrollError} when user must enroll to use biometric
 */
async function getAvailableBiometric(allowDeviceCredentials) {
  try {
    const biometricType = await _NativeBiometricsScanner.default.getAvailableBiometric(allowDeviceCredentials);
    return biometricType;
  } catch (error) {
    const errorGenerator = _errors.ErrorMap[error.code];
    throw errorGenerator ? errorGenerator() : error;
  }
}
//# sourceMappingURL=getAvailableBiometric.js.map