import BiometricsScanner from './NativeBiometricsScanner';
import { ErrorMap } from './errors';

/**
 * @param allowDeviceCredentials - check if using device credential as fallback
 * @return {Promise<BiometricType>} of the hardware
 *
 * @throws {@link UnknownBiometricError} when biometric status is unknown
 * @throws {@link UnsupportedBiometricError} when biometric is not supported
 * @throws {@link NoEnrollError} when user must enroll to use biometric
 */
export async function getAvailableBiometric(allowDeviceCredentials) {
  try {
    const biometricType = await BiometricsScanner.getAvailableBiometric(allowDeviceCredentials);
    return biometricType;
  } catch (error) {
    const errorGenerator = ErrorMap[error.code];
    throw errorGenerator ? errorGenerator() : error;
  }
}
//# sourceMappingURL=getAvailableBiometric.js.map